@@ -7,6 +7,7 @@ from .post import Post
 from .video import Video, VideoCaption
 from .photo import Photo
 from .album import Album
+from .live import LiveVideo, LiveVideoInputStream
 from .ig_basic_models import IgBasicUser, IgBasicMedia, IgBasicMediaChildren
 from .ig_pro_models import (
     IgProUser, IgProMedia, IgProComment,
@@ -28,6 +29,8 @@ __all__ = [
     "VideoCaption",
     "Photo",
     "Album",
+    "LiveVideo",
+    "LiveVideoInputStream",
     # Instagram Basic display
     "IgBasicUser",
     "IgBasicMedia",
